@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
 
+from ..models import MyObjects
 from django.db import models
-from django.db.models.signals import post_save
-from django.dispatch import receiver
 from mptt.models import MPTTModel, TreeForeignKey
-from repositories.plataforma.models import Index
 
 
 class Produto(models.Model):
@@ -33,7 +31,7 @@ class Produto(models.Model):
     altura = models.IntegerField(db_column='produto_altura', default=None, null=True)
     largura = models.IntegerField(db_column='produto_largura', default=None, null=True)
     profundidade = models.IntegerField(db_column='produto_comprimento', default=None, null=True)
-    template = models.CharField(db_column='produto_template', max_length=255, null=True, default=None)
+    # template = models.CharField(db_column='produto_template', max_length=255, null=True, default=None)
     tipo = models.CharField(db_column='produto_tipo', max_length=255, null=True)
     bloqueado = models.BooleanField(db_column='produto_bloqueado', default=False, null=False)
     usado = models.BooleanField(db_column='produto_usado', default=False, null=False)
@@ -47,14 +45,19 @@ class Produto(models.Model):
     categorias = models.ManyToManyField('catalogo.Categoria', through='ProdutoCategoria')
     destaque = models.BooleanField(db_column='produto_destaque', null=False, default=False)
 
-    cache_imagem_principal = models.ForeignKey('plataforma.Imagem', db_column='produto_cache_imagem_principal_id', null=True, on_delete=models.SET_NULL)
-    cache_url = models.CharField(db_column='produto_cache_url', max_length=255, null=True, default=None)
+    # cache_imagem_principal = models.ForeignKey('plataforma.Imagem', db_column='produto_cache_imagem_principal_id', null=True, on_delete=models.SET_NULL)
+    # cache_url = models.CharField(db_column='produto_cache_url', max_length=255, null=True, default=None)
+
+    objects = MyObjects()
 
     pai = models.ForeignKey('catalogo.Produto', db_column='produto_id_pai', null=True)
     marca = models.ForeignKey('catalogo.Marca', null=True)
     conta = models.ForeignKey('plataforma.Conta')
     contrato = models.ForeignKey('plataforma.Contrato')
 
+    data_criacao = models.DateTimeField(db_column='produto_data_criacao', auto_now_add=True)
+    data_modificacao = models.DateTimeField(db_column='produto_data_modificacao', null=True, auto_now=True)
+
     class Meta:
         app_label = "catalogo"
         db_table = u"catalogo\".\"tb_produto"
@@ -70,23 +73,13 @@ class Produto(models.Model):
             return self.cache_url
         return None
 
-    def atualizar_dados_elasticsearch(self):
-        """Cria um faz update de uma row no ProdutoIndex"""
-        if self.removido:
-            self.remover_produto_elasticsearch()
-        else:
-            filtro = dict(produto_id=self.id, conta_id=self.conta_id)
-            atualizados = Index.objects.filter(**filtro).update(status=2, status_alt=2)
-            if not atualizados:
-                Index.objects.create(status=2, status_alt=2, **filtro)
-
 
 class Categoria(MPTTModel):
     id = models.AutoField(db_column="categoria_id", primary_key=True)
     id_externo = models.IntegerField(db_column="categoria_id_externo", null=True)
 
     ativa = models.BooleanField(db_column="categoria_ativa", default=True)
-    quantidade_filhos = models.IntegerField(db_column="categoria_filhos", default=0)
+    # quantidade_filhos = models.IntegerField(db_column="categoria_filhos", default=0)
     url = models.CharField(db_column="categoria_url", null=True, max_length=255)
 
     nome = models.CharField(db_column='categoria_nome', max_length=255)
@@ -97,10 +90,21 @@ class Categoria(MPTTModel):
     conta = models.ForeignKey('plataforma.Conta', db_column="conta_id")
     contrato = models.ForeignKey('plataforma.Contrato', db_column='contrato_id')
 
+    data_criacao = models.DateTimeField(db_column="categoria_data_criacao", auto_now_add=True)
+    data_modificacao = models.DateTimeField(db_column="categoria_data_modificacao", auto_now=True)
+
+    # objects = MyObjects()
+
+    # pai = models.ForeignKey("self", db_column="categoria_id_pai", null=True, blank=True, related_name="filhos")
+    # nivel_1 = models.ForeignKey("self", db_column="categoria_id_nivel_1", null=True, blank=True, related_name="filhos_nivel_1")
+    # nivel_2 = models.ForeignKey("self", db_column="categoria_id_nivel_2", null=True, blank=True, related_name="filhos_nivel_2")
+    # nivel_3 = models.ForeignKey("self", db_column="categoria_id_nivel_3", null=True, blank=True, related_name="filhos_nivel_3")
+
     class MPTTMeta:
         order_insertion_by = ['posicao']
 
     class Meta:
+        app_label = "catalogo"
         db_table = u"catalogo\".\"tb_categoria"
 
 
@@ -109,12 +113,15 @@ class ProdutoCategoria(models.Model):
     id = models.AutoField(db_column='produto_categoria_id', primary_key=True)
     principal = models.BooleanField(db_column='produto_categoria_principal', default=False)
 
+    objects = MyObjects()
+
     produto = models.ForeignKey('catalogo.Produto', related_name='produto_categorias', on_delete=models.CASCADE)
     categoria = models.ForeignKey('catalogo.Categoria', related_name='produtos_categoria', on_delete=models.CASCADE)
     conta = models.ForeignKey('plataforma.Conta', related_name='produtos_categorias')
     contrato = models.ForeignKey('plataforma.Contrato', related_name='produtos_categorias')
 
     class Meta:
+        app_label = "catalogo"
         db_table = u"catalogo\".\"tb_produto_categoria"
 
 
@@ -124,6 +131,8 @@ class ProdutoImagem(models.Model):
     posicao = models.IntegerField(db_column='produto_imagem_posicao', null=True, default=None)
     principal = models.NullBooleanField(db_column='produto_imagem_principal', null=True, default=False)
 
+    objects = MyObjects()
+
     # Os related_name's são "produto_imagens" e "produtos_imagem" pois já existe
     # "imagens" e "produtos" dentro do produto e imagens, respectivamente,
     # referenciando ao ManyToMany de Produto x Imagem.
@@ -133,6 +142,7 @@ class ProdutoImagem(models.Model):
     contrato = models.ForeignKey('plataforma.Contrato', related_name='produtos_imagens')
 
     class Meta:
+        app_label = "catalogo"
         db_table = u'catalogo\".\"tb_produto_imagem'
         verbose_name = u'Imagem do produto'
         verbose_name_plural = u'Imagens dos produtos'
@@ -155,11 +165,14 @@ class ProdutoEstoque(models.Model):
     situacao_em_estoque = models.IntegerField(db_column='produto_estoque_situacao_em_estoque', default=0)
     situacao_sem_estoque = models.IntegerField(db_column='produto_estoque_situacao_sem_estoque', default=0)
 
+    objects = MyObjects()
+
     produto = models.OneToOneField('catalogo.Produto', related_name='estoque', on_delete=models.CASCADE)
     conta = models.ForeignKey('plataforma.Conta', related_name='produtos_estoque')
     contrato = models.ForeignKey('plataforma.Contrato', related_name='produtos_estoques')
 
     class Meta:
+        app_label = "catalogo"
         db_table = u"catalogo\".\"tb_produto_estoque"
         verbose_name = u'Estoque do Produto'
         verbose_name_plural = u"Estoque dos Produtos"
@@ -183,7 +196,30 @@ class ProdutoEstoque(models.Model):
         self.save()
 
 
-@receiver(post_save, sender=ProdutoEstoque)
-def produto_estoque_post_save(sender, instance, created, raw, **kwargs):
-    if not created:
-        instance.produto.atualizar_dados_elasticsearch()
+class Marca(models.Model):
+    """Marca."""
+    id = models.AutoField(db_column='marca_id', primary_key=True)
+    id_externo = models.IntegerField(db_column="marca_id_externo", null=True)
+
+    ativo = models.BooleanField(db_column='marca_ativo', default=False)
+    destaque = models.BooleanField(db_column="marca_destaque", default=False, null=False)
+    imagem = models.CharField(db_column="marca_imagem_caminho", null=True, blank=True, max_length=256)
+    nome = models.CharField(db_column='marca_nome', max_length=255)
+    apelido = models.CharField(db_column='marca_apelido', max_length=255, null=True)
+    descricao = models.TextField(db_column='marca_descricao', null=True)
+
+    objects = MyObjects()
+
+    conta = models.ForeignKey('plataforma.Conta', related_name='marcas', on_delete=models.CASCADE)
+    contrato = models.ForeignKey('plataforma.Contrato', related_name="marcas")
+
+    data_criacao = models.DateTimeField(db_column='marca_data_criacao', auto_now_add=True)
+    data_modificacao = models.DateTimeField(db_column='marca_data_modificacao', auto_now=True)
+
+    class Meta:
+        app_label = "catalogo"
+        db_table = u"catalogo\".\"tb_marca"
+        verbose_name = u'Marca'
+        verbose_name_plural = u'Marcas'
+        ordering = ['id']
+        get_latest_by = 'id'
