@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+from ..models import MyObjects
 from django.db import models
 from jsonfield import JSONField
 from django.utils.text import slugify
@@ -11,7 +12,10 @@ class Banco(models.Model):
     imagem = models.CharField(db_column='banco_imagem', max_length=256)
     codigo = models.CharField(db_column='banco_codigo', max_length=3)
 
+    objects = MyObjects()
+
     class Meta:
+        app_label = "configuracao"
         db_table = u"configuracao\".\"tb_banco"
         verbose_name = u'Banco'
         verbose_name_plural = u'Bancos'
@@ -32,9 +36,12 @@ class BoletoCarteira(models.Model):
     convenio = models.BooleanField(db_column="boleto_carteira_convenio", default=False, null=False)
     ativo = models.BooleanField(db_column="boleto_carteira_ativo", default=False, null=False)
 
+    objects = MyObjects()
+
     banco = models.ForeignKey('configuracao.Banco', db_column="banco_id", related_name='carteiras')
 
     class Meta:
+        app_label = "configuracao"
         db_table = u"configuracao\".\"tb_boleto_carteira"
         verbose_name = u'Carteira de boleto'
         verbose_name_plural = u'Carteiras de boletos'
@@ -49,9 +56,12 @@ class Parcela(models.Model):
     numero_parcelas = models.IntegerField(db_column="pagamento_parcela_numero_parcelas")
     fator = models.DecimalField(db_column="pagamento_parcela_fator", max_digits=16, decimal_places=6)
 
+    objects = MyObjects()
+
     forma_pagamento = models.ForeignKey('configuracao.FormaPagamento', db_column="pagamento_id", related_name="parcelas")
 
     class Meta:
+        app_label = "configuracao"
         db_table = u"configuracao\".\"tb_pagamento_parcela"
         verbose_name = u'Parcela'
         verbose_name_plural = u"Parcelas"
@@ -96,6 +106,8 @@ class FormaPagamento(models.Model):
     plano_indice = models.IntegerField(db_column='pagamento_plano_indice', default=1)
     posicao = models.IntegerField(db_column='pagamento_posicao', default=1000, null=False)
 
+    objects = MyObjects()
+
     conta = models.ForeignKey("plataforma.Conta", related_name="formas_pagamentos", null=True, default=None)
     contrato = models.ForeignKey("plataforma.Contrato", related_name="formas_pagamentos", null=True, default=None)
 
@@ -122,12 +134,15 @@ class PagamentoBanco(models.Model):
     cnpj = models.CharField(db_column="pagamento_banco_cnpj", max_length=14, null=True)
     ativo = models.BooleanField(db_column="pagamento_banco_ativo", null=False, default=False)
 
+    objects = MyObjects()
+
     banco = models.ForeignKey('configuracao.Banco', db_column="banco_id", related_name='bancos_pagamentos')
     conta = models.ForeignKey('plataforma.Conta', related_name='pagamento_bancos')
     pagamento = models.ForeignKey('configuracao.FormaPagamento', db_column="pagamento_id", related_name='bancos')
     contrato = models.ForeignKey("plataforma.Contrato", related_name="pagamento_bancos")
 
     class Meta:
+        app_label = "configuracao"
         db_table = u"configuracao\".\"tb_pagamento_banco"
         verbose_name = u'Banco para depósito'
         verbose_name_plural = u'Bancos para depósito'
@@ -179,6 +194,8 @@ class FormaPagamentoConfiguracao(models.Model):
 
     json = JSONField(db_column='pagamento_configuracao_json', null=True, default=None)
 
+    objects = MyObjects()
+
     forma_pagamento = models.ForeignKey('configuracao.FormaPagamento', db_column="pagamento_id", related_name="configuracoes")
     conta = models.ForeignKey("plataforma.Conta", related_name="formas_pagamentos_configuracoes")
     contrato = models.ForeignKey("plataforma.Contrato", related_name="formas_pagamentos_configuracoes")
@@ -187,6 +204,7 @@ class FormaPagamentoConfiguracao(models.Model):
     data_modificacao = models.DateTimeField(db_column='pagamento_configuracao_data_modificacao', null=True, auto_now=True)
 
     class Meta:
+        app_label = "configuracao"
         db_table = u"configuracao\".\"tb_pagamento_configuracao"
         verbose_name = u"Configuração da forma de pagamento"
         verbose_name_plural = u"Configurações das formas de pagamentos"
@@ -203,6 +221,8 @@ class Envio(models.Model):
     nome = models.CharField(db_column="envio_nome", max_length=128)
     codigo = models.CharField(db_column="envio_codigo", max_length=128)
 
+    objects = MyObjects()
+
     class Meta:
         app_label = "configuracao"
         db_table = u"configuracao\".\"tb_envio"
