@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+from ..models import MyObjects
 from django.db import models
 from jsonfield import JSONField
 
@@ -24,9 +25,12 @@ class DadosCobranca(models.Model):
     endereco_estado = models.CharField(db_column="dados_cobranca_endereco_estado")
     endereco_cep = models.CharField(db_column="dados_cobranca_endereco_cep")
 
+    objects = MyObjects()
+
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
 
     class Meta:
+        app_label = "faturamento"
         db_table = u"faturamento\".\"tb_dados_cobranca"
 
 
@@ -48,18 +52,21 @@ class DadosCobrancaCartao(models.Model):
     data_criacao = models.DateTimeField(db_column="dados_cobranca_cartao_data_criacao", auto_now_add=True)
     data_modificacao = models.DateTimeField(db_column="dados_cobranca_cartao_data_modificacao", auto_now=True)
 
+    objects = MyObjects()
+
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
     dados_cobranca = models.ForeignKey("DadosCobranca", db_column="dados_cobranca_id")
 
     class Meta:
+        app_label = "faturamento"
         db_table = u"faturamento\".\"tb_dados_cobranca_cartao"
 
 
 class Fatura(models.Model):
 
     FORMAS_DE_PAGAMENTO = [
-        ('BOLETO','Boleto'),
-        ('CARTAO DE CREDITOC','Cartão de Crédito')
+        ('BOLETO', 'Boleto'),
+        ('CARTAO DE CREDITOC', 'Cartão de Crédito')
     ]
 
     id = models.AutoField(db_column="fatura_id", primary_key=True)
@@ -102,10 +109,13 @@ class Fatura(models.Model):
     data_criacao = models.DateTimeField(db_column="fatura_data_criacao", auto_now_add=True)
     data_modificacao = models.DateTimeField(db_column="fatura_data_modificacao", auto_now=True)
 
+    objects = MyObjects()
+
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
     contrato = models.ForeignKey("plataforma.Contrato", db_column="contrato_id")
 
     class Meta:
+        app_label = "faturamento"
         db_table = u"faturamento\".\"tb_fatura"
 
 
@@ -121,10 +131,13 @@ class FaturaItem(models.Model):
     referencia_situacao_complementar = models.CharField(db_column="fatura_item_referencia_situacao_complementar", null=True, default=None)
     json = JSONField(db_column='fatura_item_json', null=True, default=None)
 
+    objects = MyObjects()
+
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
     fatura = models.ForeignKey("Fatura", db_column="fatura_id", related_name='itens')
 
     class Meta:
+        app_label = "faturamento"
         db_table = u"faturamento\".\"tb_fatura_item"
 
 
@@ -135,7 +148,10 @@ class Colecao(models.Model):
     data_criacao = models.DateTimeField(db_column="colecao_data_criacao", auto_now_add=True)
     data_modificacao = models.DateTimeField(db_column="colecao_data_modificacao", auto_now=True)
 
+    objects = MyObjects()
+
     class Meta:
+        app_label = "faturamento"
         db_table = u"faturamento\".\"tb_colecao"
 
 
@@ -151,6 +167,8 @@ class Plano(models.Model):
     data_criacao = models.DateTimeField(db_column="plano_data_criacao", auto_now_add=True)
     data_modificacao = models.DateTimeField(db_column="plano_data_modificacao", auto_now=True)
 
+    objects = MyObjects()
+
     colecao = models.ForeignKey("Colecao", db_column="colecao_id")
 
     class Meta:
@@ -169,11 +187,14 @@ class PlanoAssinatura(models.Model):
     data_criacao = models.DateTimeField(db_column="plano_assinatura_data_criacao", auto_now_add=True)
     data_modificacao = models.DateTimeField(db_column="plano_assinatura_data_modificacao", auto_now=True)
 
+    objects = MyObjects()
+
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
     plano = models.ForeignKey("Plano", db_column="plano_id")
     fatura = models.ForeignKey("Fatura", db_column="fatura_id")
 
     class Meta:
+        app_label = "faturamento"
         db_table = u"faturamento\".\"tb_plano_assinatura"
 
 
@@ -198,8 +219,12 @@ class Tema(models.Model):
     data_criacao = models.DateTimeField(db_column="tema_data_criacao", default=0)
     data_modificacao = models.DateTimeField(db_column="tema_data_modificacao", auto_now=True)
 
+    objects = MyObjects()
+
     colecao = models.ForeignKey("Colecao", db_column="colecao_id")
 
+    ativo = models.NullBooleanField(db_column="tema_ativo")
+
     class Meta:
         app_label = 'faturamento'
         db_table = u"faturamento\".\"tb_tema"
@@ -221,8 +246,12 @@ class Banner(models.Model):
     data_criacao = models.DateTimeField(db_column="banner_data_criacao", default=0)
     data_modificacao = models.DateTimeField(db_column="banner_data_modificacao", auto_now=True)
 
+    objects = MyObjects()
+
     colecao = models.ForeignKey("Colecao", db_column="colecao_id")
 
+    ativo = models.NullBooleanField(db_column="banner_ativo")
+
     class Meta:
         app_label = 'faturamento'
         db_table = u"faturamento\".\"tb_banner"
@@ -234,10 +263,13 @@ class Consumo(models.Model):
     data = models.DateField(db_column="consumo_data", null=False, default=None)
     data_modificacao = models.DateTimeField(db_column="consumo_data_modificacao", auto_now=True)
 
+    objects = MyObjects()
+
     trafego = models.BigIntegerField(db_column="consumo_trafego", default=0)
     visitas = models.BigIntegerField(db_column="consumo_visitas", default=0)
 
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
 
     class Meta:
-        db_table = u"faturamento\".\"tb_consumo"
\ No newline at end of file
+        app_label = "faturamento"
+        db_table = u"faturamento\".\"tb_consumo"
