@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from ..models import MyObjects
 from django.db import models
 from django.db.models.aggregates import Max
 from jsonfield import JSONField
@@ -32,10 +33,13 @@ class PedidoVendaSituacao(models.Model):
     data_criacao = models.DateTimeField(db_column="pedido_venda_situacao_data_criacao", auto_now_add=True)
     data_modificacao = models.DateTimeField(db_column="pedido_venda_situacao_data_modificacao", auto_now=True)
 
+    objects = MyObjects()
+
     conta = models.ForeignKey('plataforma.Conta', related_name='pedido_venda_situacoes', null=True, default=None)
     contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_situacoes', null=True, default=None)
 
     class Meta:
+        app_label = "pedido"
         db_table = u"pedido\".\"tb_pedido_venda_situacao"
         verbose_name = u'Situação do pedido de venda'
         verbose_name_plural = u"Situações de pedidos de vendas"
@@ -72,13 +76,16 @@ class PedidoVendaSituacaoHistorico(models.Model):
     alterado_por = models.CharField(db_column="pedido_venda_situacao_historico_alterado_por", max_length=64, null=True, choices=CHOICES_ALTERADO_POR)
     alterado_por_nome = models.CharField(db_column="pedido_venda_situacao_historico_alterado_por_nome", max_length=128, null=True)
 
+    objects = MyObjects()
+
     situacao_inicial = models.ForeignKey('pedido.PedidoVendaSituacao', db_column="pedido_venda_situacao_id_inicial", related_name='pedido_venda_situacao_inicial_historico')
     situacao_final = models.ForeignKey('pedido.PedidoVendaSituacao', db_column="pedido_venda_situacao_id_final", related_name='pedido_venda_situacao_final_historico')
     pedido = models.ForeignKey('pedido.PedidoVenda', db_column='pedido_venda_id', related_name='historico', on_delete=models.CASCADE)
     conta = models.ForeignKey('plataforma.Conta', related_name='pedido_venda_situacao_historico')
-    contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_situacao_historico')
+    # contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_situacao_historico')
 
     class Meta:
+        app_label = "pedido"
         db_table = u"pedido\".\"tb_pedido_venda_situacao_historico"
         verbose_name = u'Histórico de situações de um pedido de venda'
         verbose_name_plural = u"Histórico de situações dos pedidos de vendas"
@@ -87,18 +94,16 @@ class PedidoVendaSituacaoHistorico(models.Model):
     def __unicode__(self):
         return unicode(self.id)
 
-    def save(self, *args, **kwargs):
-        if self.conta and not self.contrato_id:
-            self.contrato_id = self.conta.contrato_id
-        super(PedidoVendaSituacaoHistorico, self).save(*args, **kwargs)
-
 
 class PedidoVendaTipo(models.Model):
     """Tipo de pedido de venda."""
     id = models.AutoField(db_column="pedido_venda_tipo_id", primary_key=True)
     nome = models.CharField(db_column="pedido_venda_tipo_nome", max_length=64)
 
+    objects = MyObjects()
+
     class Meta:
+        app_label = "pedido"
         db_table = u"pedido\".\"tb_pedido_venda_tipo"
         verbose_name = u'Tipo de pedido de venda'
         verbose_name_plural = u"Tipos de pedidos de vendas"
@@ -138,10 +143,13 @@ class PedidoVendaEndereco(models.Model):
     cep = models.CharField(db_column="pedido_venda_endereco_cep", max_length=8, null=False, blank=False)
     pais = models.CharField(db_column="pedido_venda_endereco_pais", max_length=128, null=True)
 
+    objects = MyObjects()
+
     conta = models.ForeignKey("plataforma.Conta", related_name="pedido_venda_enderecos")
     contrato = models.ForeignKey("plataforma.Contrato", related_name="pedido_venda_enderecos")
 
     class Meta:
+        app_label = "pedido"
         db_table = u"pedido\".\"tb_pedido_venda_endereco"
         verbose_name = u'Endereço do pedido de venda'
         verbose_name_plural = u"Endereços de pedidos de vendas"
@@ -161,12 +169,15 @@ class PedidoVendaFormaEnvio(models.Model):
     mensagem_correios = models.TextField(db_column="pedido_venda_envio_mensagem_correios", null=True, default=None)
     prazo = models.IntegerField(db_column='pedido_venda_envio_prazo', null=True, default=None)
 
+    objects = MyObjects()
+
     pedido = models.ForeignKey('pedido.PedidoVenda', db_column='pedido_venda_id', related_name='pedido_envios')
     envio = models.ForeignKey('configuracao.Envio', related_name='pedidos_envio')
     conta = models.ForeignKey('plataforma.Conta', related_name='pedido_venda_envios')
     contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_envios')
 
     class Meta:
+        app_label = "pedido"
         db_table = u"pedido\".\"tb_pedido_venda_envio"
         verbose_name = u'Forma de envio de um pedido de venda'
         verbose_name_plural = u"Formas de envios dos pedidos de vendas"
@@ -189,13 +200,16 @@ class PedidoVendaFormaPagamento(models.Model):
     data_modificacao = models.DateTimeField(db_column="pedido_venda_pagamento_data_modificacao", auto_now=True)
     pagamento_externo = models.BooleanField(db_column="pedido_venda_pagamento_pagamento_externo", null=False, default=False)
 
-    banco = models.ForeignKey('configuracao.PagamentoBanco', db_column='pagamento_banco_id', related_name='pedidos_banco', null=True, default=None)
+    objects = MyObjects()
+
+    banco = models.ForeignKey('configuracao.Banco', db_column='banco_id', related_name='banco')
     pedido = models.ForeignKey('pedido.PedidoVenda', db_column='pedido_venda_id', related_name='pedido_pagamentos')
     pagamento = models.ForeignKey('configuracao.FormaPagamento', related_name='pedidos_pagamento')
     conta = models.ForeignKey('plataforma.Conta', related_name='pedido_venda_pagamentos')
     contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_pagamentos')
 
     class Meta:
+        app_label = "pedido"
         db_table = u"pedido\".\"tb_pedido_venda_pagamento"
         verbose_name = u'Forma de pagamento de um pedido de venda'
         verbose_name_plural = u"Formas de pagamentos dos pedidos de vendas"
@@ -236,6 +250,8 @@ class PedidoVenda(models.Model):
     _endereco_entrega = models.OneToOneField('pedido.PedidoVendaEndereco', db_column='pedido_venda_endereco_entrega_id', related_name='+', null=False)
     _endereco_pagamento = models.OneToOneField('pedido.PedidoVendaEndereco', db_column='pedido_venda_endereco_pagamento_id', related_name='+', null=False)
 
+    objects = MyObjects()
+
     tipo = models.ForeignKey('pedido.PedidoVendaTipo', db_column='pedido_venda_tipo_id', related_name='pedidos')
     situacao = models.ForeignKey('pedido.PedidoVendaSituacao', db_column='pedido_venda_situacao_id', related_name='pedidos')
     cliente = models.ForeignKey('cliente.Cliente', related_name='pedidos')
@@ -251,6 +267,7 @@ class PedidoVenda(models.Model):
     referencia = models.TextField(db_column='pedido_venda_referencia', null=True, default=None)
 
     class Meta:
+        app_label = "pedido"
         db_table = u"pedido\".\"tb_pedido_venda"
         verbose_name = u'Pedido Venda'
         verbose_name_plural = u'Pedidos de Venda'
@@ -385,6 +402,8 @@ class PedidoVendaItem(models.Model):
     profundidade = models.IntegerField(db_column="pedido_venda_item_comprimento", default=None, null=True)
     disponibilidade = models.IntegerField(db_column="pedido_venda_item_disponibilidade", null=True)
 
+    objects = MyObjects()
+
     pedido = models.ForeignKey('pedido.PedidoVenda', db_column='pedido_venda_id', related_name='itens', on_delete=models.CASCADE)
     pedido_forma_envio = models.ForeignKey('pedido.PedidoVendaFormaEnvio', db_column="pedido_venda_envio_id", related_name='pedido_venda_itens', null=True)
     produto = models.ForeignKey("catalogo.Produto", related_name='pedido_venda_itens', on_delete=models.PROTECT)
@@ -393,6 +412,7 @@ class PedidoVendaItem(models.Model):
     contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_itens')
 
     class Meta:
+        app_label = "pedido"
         db_table = u"pedido\".\"tb_pedido_venda_item"
         verbose_name = u'Itens de um pedido de venda'
         verbose_name_plural = u"Itens dos pedidos de vendas"
@@ -400,41 +420,3 @@ class PedidoVendaItem(models.Model):
 
     def __unicode__(self):
         return unicode(self.id)
-
-    def reservar_item(self):
-        return PedidoVendaItemReserva.objects.create(
-            quantidade=self.quantidade,
-            pedido=self.pedido,
-            pedido_item=self,
-            produto=self.produto,
-            produto_pai=self.produto_pai,
-            conta=self.conta
-        )
-
-
-class PedidoVendaItemReserva(models.Model):
-    """Itens reservados de um pedido de venda."""
-    id = models.AutoField(db_column="pedido_venda_item_reserva_id", primary_key=True)
-    quantidade = models.DecimalField(db_column="pedido_venda_item_reserva_quantidade", max_digits=16, decimal_places=3)
-
-    pedido = models.ForeignKey('pedido.PedidoVenda', db_column='pedido_venda_id', related_name='itens_reservados', on_delete=models.CASCADE)
-    pedido_item = models.ForeignKey('pedido.PedidoVendaItem', db_column='pedido_venda_item_id', related_name='itens_reservados')
-    produto = models.ForeignKey("catalogo.Produto", related_name='itens_reservados')
-    produto_pai = models.ForeignKey("catalogo.Produto", db_column='produto_id_pai', related_name='filhos_itens_reservados', null=True)
-    conta = models.ForeignKey('plataforma.Conta', related_name='pedido_venda_itens_reservados')
-    contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_itens_reservados')
-
-    class Meta:
-        db_table = u"pedido\".\"tb_pedido_venda_item_reserva"
-        verbose_name = u'Itens reservados de um pedido de venda'
-        verbose_name_plural = u"Itens reservados dos pedidos de vendas"
-        ordering = ['id']
-        unique_together = (("conta", "pedido", "pedido_item"), )
-
-    def __unicode__(self):
-        return unicode(self.id)
-
-    def save(self, *args, **kwargs):
-        if self.conta and not self.contrato_id:
-            self.contrato_id = self.conta.contrato_id
-        super(PedidoVendaItemReserva, self).save(*args, **kwargs)
