@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+from ..models import MyObjects
 from django.db import models
 from jsonfield import JSONField
 
@@ -39,8 +39,15 @@ class Contrato(models.Model):
     url_termo = models.TextField(db_column="contrato_url_termo", null=True, default=None)
     headtags = models.TextField(db_column="contrato_headtags", null=True, default=None)
 
+    chave = models.CharField(db_column="contrato_chave")
+
+    objects = MyObjects()
+
     colecao = models.ForeignKey('faturamento.Colecao', db_column="colecao_id")
 
+    def __str__(self):              # __unicode__ on Python 2
+        return "%s the restaurant" % self.dominio
+
     class Meta:
         app_label = 'plataforma'
         db_table = u"plataforma\".\"tb_contrato"
@@ -49,9 +56,9 @@ class Contrato(models.Model):
 class Conta(models.Model):
 
     CONTA_SITUACOES = [
-        ('ATIVA','Loja ATIVA'),
-        ('BLOQUEADA','Loja BLOQUEADA'),
-        ('CANCELADA','Loja CANCELADA')
+        ('ATIVA', 'Loja ATIVA'),
+        ('BLOQUEADA', 'Loja BLOQUEADA'),
+        ('CANCELADA', 'Loja CANCELADA')
     ]
 
     id = models.AutoField(db_column="conta_id", primary_key=True)
@@ -60,11 +67,26 @@ class Conta(models.Model):
     email = models.CharField(db_column="conta_loja_email", max_length=128, null=True, default=None)
     dominio = models.CharField(db_column="conta_loja_dominio", max_length=128, null=True, default=None)
     situacao = models.CharField(db_column="conta_situacao", max_length=32, null=False, default='ATIVA', choices=CONTA_SITUACOES)
+    modo = models.CharField(db_column="conta_loja_modo", max_length=32, null=False, default="loja")
+
+    logo = models.CharField(db_column="conta_logo", max_length=128, null=True, default=None)
+    telefone = models.CharField(db_column="conta_loja_telefone", max_length=20, null=True, default=None)
+    whatsapp = models.CharField(db_column="conta_loja_whatsapp", max_length=20, null=True, default=None)
+    skype = models.CharField(db_column='conta_loja_skype', max_length=64, null=True, default=None)
+    endereco = models.CharField(db_column="conta_loja_endereco", max_length=128, null=True, default=None)
+
+    loja_manutencao = models.BooleanField(db_column="conta_loja_manutencao", default=False)
 
     habilitar_facebook = models.BooleanField(db_column='conta_habilitar_facebook', default=False)
     habilitar_mercadolivre = models.BooleanField(db_column='conta_habilitar_mercadolivre', default=False)
     habilitar_mobile = models.BooleanField(db_column='conta_habilitar_mobile', default=True)
 
+    data_criacao = models.DateTimeField(db_column="conta_data_criacao", auto_now_add=True)
+    data_modificacao = models.DateTimeField(db_column="conta_data_modificacao", auto_now=True, null=True)
+    data_cancelamento = models.DateTimeField(db_column="conta_data_cancelamento", null=True)
+
+    objects = MyObjects()
+
     contrato = models.ForeignKey('Contrato', db_column="contrato_id")
     plano = models.ForeignKey('faturamento.Plano', db_column="plano_id")
 
@@ -103,9 +125,12 @@ class Dominio(models.Model):
     fqdn = models.CharField(db_column="dominio_fqdn", max_length=128, null=False, unique=True)
     principal = models.BooleanField(db_column="dominio_principal", default=False, db_index=True)
 
+    objects = MyObjects()
+
     conta = models.ForeignKey("Conta", db_column="conta_id", related_name="dominios")
 
     class Meta:
+        app_label = 'plataforma'
         db_table = u"configuracao\".\"tb_dominio"
 
 
@@ -116,9 +141,12 @@ class Usuario(models.Model):
     email = models.EmailField(db_column="usuario_email")
     confirmado = models.BooleanField(db_column="usuario_confirmado", default=False)
 
+    objects = MyObjects()
+
     conta_id = models.ManyToManyField('Conta', related_name="usuarios", through="ContaUsuario")
 
     class Meta:
+        app_label = 'plataforma'
         db_table = u"plataforma\".\"tb_usuario"
 
     @property
@@ -131,10 +159,13 @@ class ContaUsuario(models.Model):
     """Relação entre conta e usuário."""
     id = models.AutoField(db_column="conta_usuario_id", primary_key=True)
 
+    objects = MyObjects()
+
     usuario = models.ForeignKey('Usuario', db_column="usuario_id")
     conta = models.ForeignKey('Conta', db_column="conta_id")
 
     class Meta:
+        app_label = 'plataforma'
         db_table = u"plataforma\".\"tb_conta_usuario"
         unique_together = ('conta', 'usuario')
 
@@ -155,7 +186,10 @@ class Certificado(models.Model):
     crt_intermediario = models.TextField(db_column="certificado_crt_intermediario", null=True)
     crt_raiz = models.TextField(db_column="certificado_crt_raiz", null=True)
 
+    objects = MyObjects()
+
     class Meta:
+        app_label = 'plataforma'
         db_table = u"plataforma\".\"tb_certificado"
 
     def __unicode__(self):
@@ -180,11 +214,14 @@ class ContaCertificado(models.Model):
 
     confirmacoes = models.IntegerField(db_column="conta_certificado_confirmacoes", null=False, default=0)
 
+    objects = MyObjects()
+
     certificado = models.ForeignKey('Certificado', related_name='contas', on_delete=models.CASCADE)
     contrato = models.ForeignKey('Contrato', db_column="contrato_id")
     conta = models.ForeignKey('Conta', db_column="conta_id")
 
     class Meta:
+        app_label = 'plataforma'
         db_table = u"plataforma\".\"tb_conta_certificado"
 
 
@@ -203,34 +240,11 @@ class Imagem(models.Model):
     tipo = models.CharField(db_column="imagem_tipo", max_length=32)
     processada = models.BooleanField(db_column="imagem_processada")
 
+    objects = MyObjects()
+
     contrato = models.ForeignKey('Contrato', db_column="contrato_id")
     conta = models.ForeignKey('Conta', db_column="conta_id")
 
     class Meta:
+        app_label = 'plataforma'
         db_table = u"plataforma\".\"tb_imagem"
-
-
-class Index(models.Model):
-    id = models.AutoField(db_column="index_id", primary_key=True)
-    status = models.IntegerField(db_column="index_status", default=1, null=False)
-    status_alt = models.IntegerField(db_column="index_status_alt", default=1, null=False)
-    produto = models.ForeignKey("catalogo.Produto", related_name='produto_index', null=True)
-    categoria = models.ForeignKey("catalogo.Categoria", related_name='categoria_indexar', null=True)
-    data_atualizacao = models.DateTimeField(db_column="index_data_atualizacao", auto_now=True)
-    conta = models.ForeignKey('plataforma.Conta', related_name='conta_indexar')
-    mensagem_erro = models.TextField(db_column="index_mensagem_erro", null=True)
-
-    class Meta:
-        db_table = u"plataforma\".\"tb_index"
-        verbose_name = u'Indexar'
-        verbose_name_plural = u"Indexar"
-
-    def indexado(self):
-        self.status = 0
-        self.save()
-
-    def erro(self, msg):
-        self.status = 1
-        self.status_alt = 1
-        self.mensagem_erro = msg
-        self.save()
